@@ -1,4 +1,3 @@
-from distutils import version
 import os
 import operator
 from functools import reduce
@@ -160,25 +159,7 @@ class FITSFigure(Layers, Regions):
         if (isinstance(data, str) and
                 data.split('.')[-1].lower() in ['png', 'jpg', 'tif']):
 
-            try:
-                from PIL import Image
-            except ImportError:
-                try:
-                    import Image
-                except ImportError:
-                    raise ImportError("The Python Imaging Library (PIL) is "
-                                      "required to read in RGB images")
-
-            try:
-                import pyavm
-            except ImportError:
-                raise ImportError("PyAVM is required to read in AVM "
-                                  "meta-data from RGB images")
-
-            if version.LooseVersion(pyavm.__version__) < version.LooseVersion('0.9.1'):
-                raise ImportError("PyAVM installation is not recent enough "
-                                  "(version 0.9.1 or later is required).")
-
+            from PIL import Image
             from pyavm import AVM
 
             # Remember image filename
@@ -259,11 +240,11 @@ class FITSFigure(Layers, Regions):
         self.set_auto_refresh(auto_refresh)
 
         # Initialize axis instance
-        if type(subplot) == list and len(subplot) == 4:
+        if type(subplot) is list and len(subplot) == 4:
             self.ax = WCSAxes(self._figure, subplot, wcs=self._wcs,
                               slices=self._wcsaxes_slices, adjustable='datalim')
             self._figure.add_axes(self.ax)
-        elif type(subplot) == tuple and len(subplot) == 3:
+        elif type(subplot) is tuple and len(subplot) == 3:
             self.ax = WCSAxesSubplot(self._figure, *subplot, wcs=self._wcs,
                                      slices=self._wcsaxes_slices)
             self._figure.add_subplot(self.ax)
@@ -339,7 +320,7 @@ class FITSFigure(Layers, Regions):
             else:
                 hdu = hdulist[hdu]
 
-        elif type(data) == np.ndarray:
+        elif type(data) is np.ndarray:
 
             hdu = fits.ImageHDU(data)
 
@@ -683,7 +664,7 @@ class FITSFigure(Layers, Regions):
         max_auto = vmax is None
 
         # The set of available functions
-        cmap = plt.cm.get_cmap(cmap)
+        cmap = plt.get_cmap(cmap)
 
         if min_auto or max_auto:
 
@@ -934,9 +915,9 @@ class FITSFigure(Layers, Regions):
             self.remove_layer(layer, raise_exception=False)
 
         if cmap:
-            cmap = plt.cm.get_cmap(cmap)
+            cmap = plt.get_cmap(cmap)
         elif not colors:
-            cmap = plt.cm.get_cmap('viridis')
+            cmap = plt.get_cmap('viridis')
 
         if data is not None:
             data_contour, header_contour, wcs_contour, wcsaxes_slices = \
@@ -951,7 +932,7 @@ class FITSFigure(Layers, Regions):
         wcs_contour.ny = header_contour['NAXIS%i' % (dimensions[1] + 1)]
 
         image_contour = convolve_util.convolve(data_contour, smooth=smooth, kernel=kernel)
-        if type(levels) == int:
+        if type(levels) is int:
             interval = AsymmetricPercentileInterval(0.25, 99.75, n_samples=10000)
             try:
                 vmin_auto, vmax_auto = interval.get_limits(image_contour)
@@ -1772,7 +1753,7 @@ class FITSFigure(Layers, Regions):
             self._figure.canvas.draw()
 
     def save(self, filename, dpi=None, transparent=False, adjust_bbox=True,
-             max_dpi=300, format=None):
+             max_dpi=300, format=None, **savefig_kwargs):
         """
         Save the current figure to a file.
 
@@ -1806,6 +1787,9 @@ class FITSFigure(Layers, Regions):
             By default, APLpy tries to guess the file format based on the
             file extension, but the format can also be specified
             explicitly. Should be one of 'eps', 'ps', 'pdf', 'svg', 'png'.
+
+        **savefig_kwargs
+            Additional keywords are passed to Matplotlib's ``savefig()``
         """
 
         if isinstance(filename, str) and format is None:
@@ -1823,10 +1807,10 @@ class FITSFigure(Layers, Regions):
 
         if adjust_bbox:
             self._figure.savefig(filename, dpi=dpi, transparent=transparent,
-                                 bbox_inches='tight', format=format)
+                                 bbox_inches='tight', format=format, **savefig_kwargs)
         else:
             self._figure.savefig(filename, dpi=dpi, transparent=transparent,
-                                 format=format)
+                                 format=format, **savefig_kwargs)
 
     def _initialize_view(self):
         self.ax.set_xlim(-0.5, self._wcs.nx - 0.5)
@@ -1863,7 +1847,7 @@ class FITSFigure(Layers, Regions):
             self._figure.apl_grayscale_invert_default = False
             self._figure.apl_colorscale_cmap_default = 'viridis'
             if self.image:
-                self.image.set_cmap(cmap=plt.cm.get_cmap('viridis'))
+                self.image.set_cmap(cmap=plt.get_cmap('viridis'))
         elif theme == 'publication':
             self.frame.set_color('black')
             self.frame.set_linewidth(1.0)
@@ -1872,7 +1856,7 @@ class FITSFigure(Layers, Regions):
             self._figure.apl_grayscale_invert_default = True
             self._figure.apl_colorscale_cmap_default = 'gist_heat'
             if self.image:
-                self.image.set_cmap(cmap=plt.cm.get_cmap('gist_yarg'))
+                self.image.set_cmap(cmap=plt.get_cmap('gist_yarg'))
 
     def world2pixel(self, xw, yw, wcs=None):
         """
@@ -2107,4 +2091,5 @@ class FITSFigure(Layers, Regions):
         """
         plt.close(self._figure)
 
-    savefig = save
+    def savefig(self, *args, **kwargs):
+        return self.save(*args, **kwargs)
